@@ -1,6 +1,6 @@
 package Net::Kubernetes;
 # ABSTRACT: An object oriented interface to the REST API's provided by kubernetes
-$Net::Kubernetes::VERSION = '0.21';
+$Net::Kubernetes::VERSION = '0.22';
 use Moose;
 require Net::Kubernetes::Namespace;
 require LWP::UserAgent;
@@ -36,6 +36,9 @@ sub get_namespace {
 		my(%create_args) = (url => $self->url, base_path=>$ns->{metadata}{selfLink}, api_version=>$self->api_version, namespace=> $namespace, _namespace_data=>$ns);
 		$create_args{username} = $self->username if(defined $self->username);
 		$create_args{password} = $self->password if(defined $self->password);
+		$create_args{ssl_cert_file} = $self->ssl_cert_file if(defined $self->ssl_cert_file);
+		$create_args{ssl_key_file} = $self->ssl_key_file if(defined $self->ssl_key_file);
+		$create_args{ssl_ca_file} = $self->ssl_ca_file if(defined $self->ssl_ca_file);
 		return Net::Kubernetes::Namespace->new(%create_args);
 	}else{
 		Net::Kubernetes::Exception->throw(code=>$res->code, message=>"Error getting namespace $namespace:\n".$res->message);
@@ -130,7 +133,7 @@ Net::Kubernetes - An object oriented interface to the REST API's provided by kub
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -181,6 +184,12 @@ An authentication token to be used to access the apiserver.  This may be provide
 from which to read the token (like /var/run/secrets/kubernetes.io/serviceaccount/token from within a pod), or a reference
 to a file handle (from which to read the token).
 
+=item ssl_cert_file, ssl_key_file, ssl_ca_file
+
+This there options passed into new will cause Net::Kubernetes in inlcude SSL client certs to requests to the kuberernetes
+API server for authentication.  There are basically just a passthrough to the underlying LWP::UserAgent used to handle the 
+api requests.
+
 =back
 
 =head2 get_namespace("myNamespace");
