@@ -1,6 +1,6 @@
 package Net::Kubernetes::Role::ResourceFactory;
 # ABSTRACT: Role to allow easy construction of Net::Kubernetes::Resouce::* objects
-$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.21';
+$Net::Kubernetes::Role::ResourceFactory::VERSION = '0.22';
 use Moose::Role;
 use MooseX::Aliases;
 require Net::Kubernetes::Resource::Endpoint;
@@ -21,6 +21,9 @@ sub create_resource_object {
 	$create_args{password} = $self->password if($self->password);
 	$create_args{url} = $self->url;
 	$create_args{base_path} = $object->{metadata}{selfLink};
+	$create_args{ssl_cert_file} = $self->ssl_cert_file if($self->ssl_cert_file);
+	$create_args{ssl_key_file} = $self->ssl_key_file if($self->ssl_key_file);
+	$create_args{ssl_ca_file} = $self->ssl_ca_file if($self->ssl_ca_file);
 	my $class = "Net::Kubernetes::Resource::".$kind;
 	return $class->new(%create_args);
 }
@@ -40,7 +43,7 @@ Net::Kubernetes::Role::ResourceFactory - Role to allow easy construction of Net:
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 AUTHOR
 
